@@ -7,6 +7,7 @@
 #include <stddef.h>
 #include <stdint.h>
 
+#include <memory>
 #include <sstream>
 #include <string>
 #include <vector>
@@ -603,7 +604,7 @@ TEST(ProcessMetricsTest, DISABLED_GetNumberOfThreads) {
   {
     std::unique_ptr<Thread> my_threads[kNumAdditionalThreads];
     for (int i = 0; i < kNumAdditionalThreads; ++i) {
-      my_threads[i].reset(new Thread("GetNumberOfThreadsTest"));
+      my_threads[i] = std::make_unique<Thread>("GetNumberOfThreadsTest");
       my_threads[i]->Start();
       ASSERT_EQ(GetNumberOfThreads(current), initial_threads + 1 + i);
     }
@@ -885,28 +886,5 @@ TEST(ProcessMetricsTestLinux, GetPerThreadCumulativeCPUTimeInState) {
 
 #endif  // defined(OS_ANDROID) || defined(OS_LINUX) || defined(OS_CHROMEOS)
 
-#if defined(OS_WIN)
-TEST(ProcessMetricsTest, GetDiskUsageBytesPerSecond) {
-  ScopedTempDir temp_dir;
-  ASSERT_TRUE(temp_dir.CreateUniqueTempDir());
-  const FilePath temp_path = temp_dir.GetPath().AppendASCII("dummy");
-
-  ProcessHandle handle = GetCurrentProcessHandle();
-  std::unique_ptr<ProcessMetrics> metrics(
-      ProcessMetrics::CreateProcessMetrics(handle));
-
-  // First access is returning zero bytes.
-  EXPECT_EQ(metrics->GetDiskUsageBytesPerSecond(), 0U);
-
-  // Write a megabyte on disk.
-  const int kMegabyte = 1024 * 1014;
-  std::string data(kMegabyte, 'x');
-  ASSERT_TRUE(base::WriteFile(temp_path, data));
-
-  // Validate that the counters move up.
-  EXPECT_GT(metrics->GetDiskUsageBytesPerSecond(), 0U);
-}
-#endif  // defined(OS_WIN)
-
 }  // namespace debug
 }  // namespace base
