@@ -18,11 +18,11 @@
 #include "chrome/browser/extensions/extension_apitest.h"
 #include "chrome/browser/extensions/extension_function_test_utils.h"
 #include "chrome/browser/extensions/extension_management_test_util.h"
-#include "chrome/browser/infobars/infobar_service.h"
 #include "chrome/browser/ui/tabs/tab_strip_model.h"
 #include "chrome/common/chrome_paths.h"
 #include "chrome/common/chrome_switches.h"
 #include "chrome/test/base/ui_test_utils.h"
+#include "components/infobars/content/content_infobar_manager.h"
 #include "components/infobars/core/infobar.h"
 #include "components/infobars/core/infobar_delegate.h"
 #include "components/policy/core/common/mock_configuration_policy_provider.h"
@@ -201,9 +201,9 @@ IN_PROC_BROWSER_TEST_F(DebuggerApiTest,
 
 IN_PROC_BROWSER_TEST_F(DebuggerApiTest,
                        DebuggerAllowedOnFileUrlsWithFileAccess) {
-  EXPECT_TRUE(RunExtensionTest(
-      {.name = "debugger_file_access", .custom_arg = "enabled"},
-      {.allow_file_access = true}))
+  EXPECT_TRUE(RunExtensionTest("debugger_file_access",
+                               {.custom_arg = "enabled"},
+                               {.allow_file_access = true}))
       << message_;
 }
 
@@ -227,12 +227,15 @@ IN_PROC_BROWSER_TEST_F(DebuggerApiTest, InfoBar) {
                     another_browser->tab_strip_model()->GetActiveWebContents())
                     .id();
 
-  InfoBarService* service1 = InfoBarService::FromWebContents(
-      browser()->tab_strip_model()->GetActiveWebContents());
-  InfoBarService* service2 = InfoBarService::FromWebContents(
-      another_browser->tab_strip_model()->GetWebContentsAt(0));
-  InfoBarService* service3 = InfoBarService::FromWebContents(
-      another_browser->tab_strip_model()->GetWebContentsAt(1));
+  infobars::ContentInfoBarManager* manager1 =
+      infobars::ContentInfoBarManager::FromWebContents(
+          browser()->tab_strip_model()->GetActiveWebContents());
+  infobars::ContentInfoBarManager* manager2 =
+      infobars::ContentInfoBarManager::FromWebContents(
+          another_browser->tab_strip_model()->GetWebContentsAt(0));
+  infobars::ContentInfoBarManager* manager3 =
+      infobars::ContentInfoBarManager::FromWebContents(
+          another_browser->tab_strip_model()->GetWebContentsAt(1));
 
   // Attaching to one tab should create infobars in both browsers.
   attach_function = new DebuggerAttachFunction();
@@ -241,9 +244,9 @@ IN_PROC_BROWSER_TEST_F(DebuggerApiTest, InfoBar) {
       attach_function.get(),
       base::StringPrintf("[{\"tabId\": %d}, \"1.1\"]", tab_id), browser(),
       api_test_utils::NONE));
-  EXPECT_EQ(1u, service1->infobar_count());
-  EXPECT_EQ(1u, service2->infobar_count());
-  EXPECT_EQ(1u, service3->infobar_count());
+  EXPECT_EQ(1u, manager1->infobar_count());
+  EXPECT_EQ(1u, manager2->infobar_count());
+  EXPECT_EQ(1u, manager3->infobar_count());
 
   // Attaching to another tab should not create more infobars.
   attach_function = new DebuggerAttachFunction();
@@ -252,9 +255,9 @@ IN_PROC_BROWSER_TEST_F(DebuggerApiTest, InfoBar) {
       attach_function.get(),
       base::StringPrintf("[{\"tabId\": %d}, \"1.1\"]", tab_id2), browser(),
       api_test_utils::NONE));
-  EXPECT_EQ(1u, service1->infobar_count());
-  EXPECT_EQ(1u, service2->infobar_count());
-  EXPECT_EQ(1u, service3->infobar_count());
+  EXPECT_EQ(1u, manager1->infobar_count());
+  EXPECT_EQ(1u, manager2->infobar_count());
+  EXPECT_EQ(1u, manager3->infobar_count());
 
   // Detaching from one of the tabs should not remove infobars.
   detach_function = new DebuggerDetachFunction();
@@ -262,9 +265,9 @@ IN_PROC_BROWSER_TEST_F(DebuggerApiTest, InfoBar) {
   ASSERT_TRUE(extension_function_test_utils::RunFunction(
       detach_function.get(), base::StringPrintf("[{\"tabId\": %d}]", tab_id2),
       browser(), api_test_utils::NONE));
-  EXPECT_EQ(1u, service1->infobar_count());
-  EXPECT_EQ(1u, service2->infobar_count());
-  EXPECT_EQ(1u, service3->infobar_count());
+  EXPECT_EQ(1u, manager1->infobar_count());
+  EXPECT_EQ(1u, manager2->infobar_count());
+  EXPECT_EQ(1u, manager3->infobar_count());
 
   // Detaching from the other tab also should not remove infobars, since even
   // though there is no longer an extension attached, the infobar can only be
@@ -274,9 +277,9 @@ IN_PROC_BROWSER_TEST_F(DebuggerApiTest, InfoBar) {
   ASSERT_TRUE(extension_function_test_utils::RunFunction(
       detach_function.get(), base::StringPrintf("[{\"tabId\": %d}]", tab_id),
       browser(), api_test_utils::NONE));
-  EXPECT_EQ(1u, service1->infobar_count());
-  EXPECT_EQ(1u, service2->infobar_count());
-  EXPECT_EQ(1u, service3->infobar_count());
+  EXPECT_EQ(1u, manager1->infobar_count());
+  EXPECT_EQ(1u, manager2->infobar_count());
+  EXPECT_EQ(1u, manager3->infobar_count());
 
   // Attach again; should not create infobars.
   attach_function = new DebuggerAttachFunction();
@@ -285,19 +288,19 @@ IN_PROC_BROWSER_TEST_F(DebuggerApiTest, InfoBar) {
       attach_function.get(),
       base::StringPrintf("[{\"tabId\": %d}, \"1.1\"]", tab_id), browser(),
       api_test_utils::NONE));
-  EXPECT_EQ(1u, service1->infobar_count());
-  EXPECT_EQ(1u, service2->infobar_count());
-  EXPECT_EQ(1u, service3->infobar_count());
+  EXPECT_EQ(1u, manager1->infobar_count());
+  EXPECT_EQ(1u, manager2->infobar_count());
+  EXPECT_EQ(1u, manager3->infobar_count());
 
   // Remove the global infobar by simulating what happens when the user clicks
   // the close button (see InfoBarView::ButtonPressed()).  The
   // InfoBarDismissed() call will remove the infobars everywhere except on
-  // |service2| itself; the RemoveSelf() call removes that one.
-  service2->infobar_at(0)->delegate()->InfoBarDismissed();
-  service2->infobar_at(0)->RemoveSelf();
-  EXPECT_EQ(0u, service1->infobar_count());
-  EXPECT_EQ(0u, service2->infobar_count());
-  EXPECT_EQ(0u, service3->infobar_count());
+  // |manager2| itself; the RemoveSelf() call removes that one.
+  manager2->infobar_at(0)->delegate()->InfoBarDismissed();
+  manager2->infobar_at(0)->RemoveSelf();
+  EXPECT_EQ(0u, manager1->infobar_count());
+  EXPECT_EQ(0u, manager2->infobar_count());
+  EXPECT_EQ(0u, manager3->infobar_count());
   detach_function = new DebuggerDetachFunction();
   detach_function->set_extension(extension());
   // Cannot detach again.
@@ -312,21 +315,21 @@ IN_PROC_BROWSER_TEST_F(DebuggerApiTest, InfoBar) {
       attach_function.get(),
       base::StringPrintf("[{\"tabId\": %d}, \"1.1\"]", tab_id), browser(),
       api_test_utils::NONE));
-  EXPECT_EQ(1u, service1->infobar_count());
-  EXPECT_EQ(1u, service2->infobar_count());
-  EXPECT_EQ(1u, service3->infobar_count());
+  EXPECT_EQ(1u, manager1->infobar_count());
+  EXPECT_EQ(1u, manager2->infobar_count());
+  EXPECT_EQ(1u, manager3->infobar_count());
 
   // Closing tab should not affect anything.
   ASSERT_TRUE(another_browser->tab_strip_model()->CloseWebContentsAt(1, 0));
-  service3 = nullptr;
-  EXPECT_EQ(1u, service1->infobar_count());
-  EXPECT_EQ(1u, service2->infobar_count());
+  manager3 = nullptr;
+  EXPECT_EQ(1u, manager1->infobar_count());
+  EXPECT_EQ(1u, manager2->infobar_count());
 
   // Closing browser should not affect anything.
   CloseBrowserSynchronously(another_browser);
-  service2 = nullptr;
+  manager2 = nullptr;
   another_browser = nullptr;
-  EXPECT_EQ(1u, service1->infobar_count());
+  EXPECT_EQ(1u, manager1->infobar_count());
 
   // Detach should not affect anything.
   detach_function = new DebuggerDetachFunction();
@@ -334,15 +337,16 @@ IN_PROC_BROWSER_TEST_F(DebuggerApiTest, InfoBar) {
   ASSERT_TRUE(extension_function_test_utils::RunFunction(
       detach_function.get(), base::StringPrintf("[{\"tabId\": %d}]", tab_id),
       browser(), api_test_utils::NONE));
-  EXPECT_EQ(1u, service1->infobar_count());
+  EXPECT_EQ(1u, manager1->infobar_count());
 }
 
 IN_PROC_BROWSER_TEST_F(DebuggerApiTest, InfoBarIsRemovedAfterFiveSeconds) {
   int tab_id = sessions::SessionTabHelper::IdForTab(
                    browser()->tab_strip_model()->GetActiveWebContents())
                    .id();
-  InfoBarService* service = InfoBarService::FromWebContents(
-      browser()->tab_strip_model()->GetActiveWebContents());
+  infobars::ContentInfoBarManager* manager =
+      infobars::ContentInfoBarManager::FromWebContents(
+          browser()->tab_strip_model()->GetActiveWebContents());
 
   // Attaching to the tab should create an infobar.
   auto attach_function = base::MakeRefCounted<DebuggerAttachFunction>();
@@ -351,7 +355,7 @@ IN_PROC_BROWSER_TEST_F(DebuggerApiTest, InfoBarIsRemovedAfterFiveSeconds) {
       attach_function.get(),
       base::StringPrintf("[{\"tabId\": %d}, \"1.1\"]", tab_id), browser(),
       api_test_utils::NONE));
-  EXPECT_EQ(1u, service->infobar_count());
+  EXPECT_EQ(1u, manager->infobar_count());
 
   // Detaching from the tab should remove the infobar after 5 seconds.
   auto detach_function = base::MakeRefCounted<DebuggerDetachFunction>();
@@ -367,13 +371,13 @@ IN_PROC_BROWSER_TEST_F(DebuggerApiTest, InfoBarIsRemovedAfterFiveSeconds) {
   base::ThreadTaskRunnerHandle::Get()->PostDelayedTask(
       FROM_HERE, run_loop.QuitClosure(),
       ExtensionDevToolsInfoBarDelegate::kAutoCloseDelay);
-  EXPECT_EQ(1u, service->infobar_count());  // Infobar is still shown.
+  EXPECT_EQ(1u, manager->infobar_count());  // Infobar is still shown.
 
   // Advance the clock by 5 seconds, and verify the infobar is removed.
   AdvanceClock(ExtensionDevToolsInfoBarDelegate::kAutoCloseDelay);
   run_loop.Run();
 
-  EXPECT_EQ(0u, service->infobar_count());
+  EXPECT_EQ(0u, manager->infobar_count());
 }
 
 IN_PROC_BROWSER_TEST_F(DebuggerApiTest,
@@ -381,8 +385,9 @@ IN_PROC_BROWSER_TEST_F(DebuggerApiTest,
   int tab_id = sessions::SessionTabHelper::IdForTab(
                    browser()->tab_strip_model()->GetActiveWebContents())
                    .id();
-  InfoBarService* service = InfoBarService::FromWebContents(
-      browser()->tab_strip_model()->GetActiveWebContents());
+  infobars::ContentInfoBarManager* manager =
+      infobars::ContentInfoBarManager::FromWebContents(
+          browser()->tab_strip_model()->GetActiveWebContents());
 
   // Attaching to the tab should create an infobar.
   auto attach_function = base::MakeRefCounted<DebuggerAttachFunction>();
@@ -391,7 +396,7 @@ IN_PROC_BROWSER_TEST_F(DebuggerApiTest,
       attach_function.get(),
       base::StringPrintf("[{\"tabId\": %d}, \"1.1\"]", tab_id), browser(),
       api_test_utils::NONE));
-  EXPECT_EQ(1u, service->infobar_count());
+  EXPECT_EQ(1u, manager->infobar_count());
 
   // Detaching from the tab and attaching it again before 5 seconds should not
   // remove the infobar.
@@ -400,7 +405,7 @@ IN_PROC_BROWSER_TEST_F(DebuggerApiTest,
   ASSERT_TRUE(extension_function_test_utils::RunFunction(
       detach_function.get(), base::StringPrintf("[{\"tabId\": %d}]", tab_id),
       browser(), api_test_utils::NONE));
-  EXPECT_EQ(1u, service->infobar_count());
+  EXPECT_EQ(1u, manager->infobar_count());
 
   attach_function = base::MakeRefCounted<DebuggerAttachFunction>();
   attach_function->set_extension(extension());
@@ -409,7 +414,7 @@ IN_PROC_BROWSER_TEST_F(DebuggerApiTest,
       base::StringPrintf("[{\"tabId\": %d}, \"1.1\"]", tab_id), browser(),
       api_test_utils::NONE));
   // Verify that only one infobar is created.
-  EXPECT_EQ(1u, service->infobar_count());
+  EXPECT_EQ(1u, manager->infobar_count());
 
   // Verify that infobar is not closed after 5 seconds.
   base::RunLoop run_loop;
@@ -419,7 +424,7 @@ IN_PROC_BROWSER_TEST_F(DebuggerApiTest,
   AdvanceClock(ExtensionDevToolsInfoBarDelegate::kAutoCloseDelay);
   run_loop.Run();
 
-  EXPECT_EQ(1u, service->infobar_count());
+  EXPECT_EQ(1u, manager->infobar_count());
 }
 
 // Tests that policy blocked hosts supersede the `debugger`
@@ -462,8 +467,8 @@ IN_PROC_BROWSER_TEST_F(DebuggerExtensionApiTest,
   GURL url(embedded_test_server()->GetURL(
       "/extensions/api_test/debugger_inspect_worker/inspected_page.html"));
 
-  EXPECT_TRUE(RunExtensionTest(
-      {.name = "debugger_inspect_worker", .custom_arg = url.spec().c_str()}))
+  EXPECT_TRUE(RunExtensionTest("debugger_inspect_worker",
+                               {.custom_arg = url.spec().c_str()}))
       << message_;
 }
 
@@ -503,8 +508,8 @@ IN_PROC_BROWSER_TEST_F(SitePerProcessDebuggerExtensionApiTest, Debugger) {
   navigation_manager_iframe.WaitForNavigationFinished();
   EXPECT_TRUE(content::WaitForLoadStop(tab));
 
-  ASSERT_TRUE(RunExtensionTest(
-      {.name = "debugger", .custom_arg = "oopif.html;oopif_frame.html"}))
+  ASSERT_TRUE(RunExtensionTest("debugger",
+                               {.custom_arg = "oopif.html;oopif_frame.html"}))
       << message_;
 }
 
@@ -513,8 +518,8 @@ IN_PROC_BROWSER_TEST_F(SitePerProcessDebuggerExtensionApiTest,
   GURL url(embedded_test_server()->GetURL(
       "a.com",
       "/extensions/api_test/debugger_navigate_subframe/inspected_page.html"));
-  ASSERT_TRUE(RunExtensionTest(
-      {.name = "debugger_navigate_subframe", .custom_arg = url.spec().c_str()}))
+  ASSERT_TRUE(RunExtensionTest("debugger_navigate_subframe",
+                               {.custom_arg = url.spec().c_str()}))
       << message_;
 }
 
@@ -523,8 +528,8 @@ IN_PROC_BROWSER_TEST_F(SitePerProcessDebuggerExtensionApiTest,
   GURL url(embedded_test_server()->GetURL(
       "a.com",
       "/extensions/api_test/debugger_auto_attach_permissions/page.html"));
-  ASSERT_TRUE(RunExtensionTest({.name = "debugger_auto_attach_permissions",
-                                .custom_arg = url.spec().c_str()}))
+  ASSERT_TRUE(RunExtensionTest("debugger_auto_attach_permissions",
+                               {.custom_arg = url.spec().c_str()}))
       << message_;
 }
 
