@@ -2,19 +2,17 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+// <if expr="enable_ink">
+import './elements/viewer-ink-host.js';
+// </if>
 import './elements/viewer-password-dialog.js';
 import './elements/viewer-properties-dialog.js';
 import './elements/shared-vars.js';
-// <if expr="chromeos">
-import './elements/viewer-ink-host.js';
-import './elements/viewer-form-warning.js';
-// </if>
 import './pdf_viewer_shared_style.js';
 import 'chrome://resources/cr_elements/hidden_style_css.m.js';
 import 'chrome://resources/cr_elements/shared_vars_css.m.js';
 
 import {assert, assertNotReached} from 'chrome://resources/js/assert.m.js';
-import {FocusOutlineManager} from 'chrome://resources/js/cr/ui/focus_outline_manager.m.js';
 import {loadTimeData} from 'chrome://resources/js/load_time_data.m.js';
 import {hasKeyModifiers, listenOnce} from 'chrome://resources/js/util.m.js';
 import {html} from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min.js';
@@ -23,10 +21,10 @@ import {Bookmark} from './bookmark_type.js';
 import {BrowserApi} from './browser_api.js';
 import {Attachment, DocumentMetadata, FittingType, Point, SaveRequestType} from './constants.js';
 import {PluginController} from './controller.js';
-import {ViewerErrorScreenElement} from './elements/viewer-error-screen.js';
+import {ViewerErrorDialogElement} from './elements/viewer-error-dialog.js';
 import {ViewerPdfSidenavElement} from './elements/viewer-pdf-sidenav.js';
-import {ViewerPdfToolbarNewElement} from './elements/viewer-pdf-toolbar-new.js';
-// <if expr="chromeos">
+import {ViewerToolbarElement} from './elements/viewer-toolbar.js';
+// <if expr="enable_ink">
 import {InkController, InkControllerEventType} from './ink_controller.js';
 //</if>
 import {LocalStorageProxyImpl} from './local_storage_proxy.js';
@@ -35,7 +33,7 @@ import {NavigatorDelegateImpl, PdfNavigator, WindowOpenDisposition} from './navi
 import {OpenPdfParamsParser} from './open_pdf_params_parser.js';
 import {DeserializeKeyEvent, LoadState, SerializeKeyEvent} from './pdf_scripting_api.js';
 import {PDFViewerBaseElement} from './pdf_viewer_base.js';
-import {DestinationMessageData, DocumentDimensionsMessageData, shouldIgnoreKeyEvents} from './pdf_viewer_utils.js';
+import {DestinationMessageData, DocumentDimensionsMessageData, hasCtrlModifier, shouldIgnoreKeyEvents} from './pdf_viewer_utils.js';
 
 
 /**
@@ -177,12 +175,6 @@ export class PDFViewerElement extends PDFViewerBaseElement {
         value: () => {},
       },
 
-      /** @private */
-      documentPropertiesEnabled_: {
-        type: Boolean,
-        value: false,
-      },
-
       /** @private */
       fileName_: String,
 
@@ -228,12 +220,6 @@ export class PDFViewerElement extends PDFViewerBaseElement {
         value: false,
       },
 
-      /** @private */
-      presentationModeEnabled_: {
-        type: Boolean,
-        value: false,
-      },
-
       /** @private */
       printingEnabled_: {
         type: Boolean,
@@ -286,8 +272,8 @@ export class PDFViewerElement extends PDFViewerBaseElement {
 
     // TODO(dpapad): Add tests after crbug.com/1111459 is fixed.
     this.sidenavCollapsed_ = Boolean(Number.parseInt(
-        LocalStorageProxyImpl.getInstance().getItem(
-            LOCAL_STORAGE_SIDENAV_COLLAPSED_KEY),
+        /** @type {string} */ (LocalStorageProxyImpl.getInstance().getItem(
+            LOCAL_STORAGE_SIDENAV_COLLAPSED_KEY)),
         10));
 
     // Non-Polymer properties
@@ -310,12 +296,10 @@ export class PDFViewerElement extends PDFViewerBaseElement {
     /** @private {?PluginController} */
     this.pluginController_ = null;
 
-    // <if expr="chromeos">
+    // <if expr="enable_ink">
     /** @private {?InkController} */
     this.inkController_ = null;
     // </if>
-
-    FocusOutlineManager.forDocument(document);
   }
 
   /** @override */
@@ -328,17 +312,12 @@ export class PDFViewerElement extends PDFViewerBaseElement {
     return /** @type {!HTMLDivElement} */ (this.$$('#sizer'));
   }
 
-  /** @override */
-  getErrorScreen() {
-    return /** @type {!ViewerErrorScreenElement} */ (this.$$('#error-screen'));
-  }
-
   /**
-   * @return {!ViewerPdfToolbarNewElement}
+   * @return {!ViewerToolbarElement}
    * @private
    */
   getToolbar_() {
-    return /** @type {!ViewerPdfToolbarNewElement} */ (this.$$('#toolbar'));
+    return /** @type {!ViewerToolbarElement} */ (this.$$('#toolbar'));
   }
 
   /** @override */
@@ -352,7 +331,7 @@ export class PDFViewerElement extends PDFViewerBaseElement {
 
     this.pluginController_ = PluginController.getInstance();
 
-    // <if expr="chromeos">
+    // <if expr="enable_ink">
     this.inkController_ = InkController.getInstance();
     this.inkController_.init(
         this.viewport, /** @type {!HTMLDivElement} */ (this.getContent()));
@@ -394,6 +373,7 @@ export class PDFViewerElement extends PDFViewerBaseElement {
    * @private
    */
   handleToolbarKeyEvent_(e) {
+    // TODO(thestig): Should this use hasCtrlModifier() or stay as is?
     if (e.key === '\\' && e.ctrlKey) {
       this.getToolbar_().fitToggle();
     }
@@ -419,12 +399,9 @@ export class PDFViewerElement extends PDFViewerBaseElement {
 
     if (document.fullscreenElement !== null) {
       // Disable zoom shortcuts in Presentation mode.
-      let hasModifier = e.ctrlKey;
-      // <if expr="is_macosx">
-      hasModifier = e.metaKey;
-      // </if>
       // Handle '+' and '-' buttons (both in the numpad and elsewhere).
-      if (hasModifier && (e.key === '=' || e.key === '-' || e.key === '+')) {
+      if (hasCtrlModifier(e) &&
+          (e.key === '=' || e.key === '-' || e.key === '+')) {
         e.preventDefault();
       }
 
@@ -434,18 +411,22 @@ export class PDFViewerElement extends PDFViewerBaseElement {
 
     switch (e.key) {
       case 'a':
-        if (e.ctrlKey || e.metaKey) {
+        if (hasCtrlModifier(e)) {
           this.pluginController_.selectAll();
           // Since we do selection ourselves.
           e.preventDefault();
         }
         return;
       case '[':
+        // Do not use hasCtrlModifier() here, since Command + [ is already
+        // taken by the "go back to the previous webpage" action.
         if (e.ctrlKey) {
           this.rotateCounterclockwise();
         }
         return;
       case ']':
+        // Do not use hasCtrlModifier() here, since Command + ] is already
+        // taken by the "go forward to the next webpage" action.
         if (e.ctrlKey) {
           this.rotateClockwise();
         }
@@ -456,7 +437,7 @@ export class PDFViewerElement extends PDFViewerBaseElement {
     this.handleToolbarKeyEvent_(e);
   }
 
-  // <if expr="chromeos">
+  // <if expr="enable_ink">
   /** @private */
   onResetView_() {
     if (this.twoUpViewEnabled_) {
@@ -604,8 +585,6 @@ export class PDFViewerElement extends PDFViewerBaseElement {
 
   /** @private */
   onPresentClick_() {
-    assert(this.presentationModeEnabled_);
-
     const onWheel = e => {
       e.deltaY > 0 ? this.viewport.goToNextPage() :
                      this.viewport.goToPreviousPage();
@@ -645,7 +624,6 @@ export class PDFViewerElement extends PDFViewerBaseElement {
 
   /** @private */
   onPropertiesClick_() {
-    assert(this.documentPropertiesEnabled_);
     assert(!this.showPropertiesDialog_);
     this.showPropertiesDialog_ = true;
   }
@@ -708,6 +686,20 @@ export class PDFViewerElement extends PDFViewerBaseElement {
     super.updateProgress(progress);
   }
 
+  /** @private */
+  onErrorDialog_() {
+    // The error screen can only reload from a normal tab.
+    if (!chrome.tabs || this.browserApi.getStreamInfo().tabId === -1) {
+      return;
+    }
+
+    const errorDialog = /** @type {!ViewerErrorDialogElement} */ (
+        this.shadowRoot.querySelector('#error-dialog'));
+    errorDialog.reloadFn = () => {
+      chrome.tabs.reload(this.browserApi.getStreamInfo().tabId);
+    };
+  }
+
   /** @private */
   closePasswordDialog_() {
     const passwordDialog = this.shadowRoot.querySelector('#password-dialog');
@@ -745,12 +737,8 @@ export class PDFViewerElement extends PDFViewerBaseElement {
   handleStrings(strings) {
     super.handleStrings(strings);
 
-    this.documentPropertiesEnabled_ =
-        loadTimeData.getBoolean('documentPropertiesEnabled');
     this.pdfAnnotationsEnabled_ =
         loadTimeData.getBoolean('pdfAnnotationsEnabled');
-    this.presentationModeEnabled_ =
-        loadTimeData.getBoolean('presentationModeEnabled');
     this.printingEnabled_ = loadTimeData.getBoolean('printingEnabled');
     const presetZoomFactors = this.viewport.presetZoomFactors;
     this.zoomBounds_.min = Math.round(presetZoomFactors[0] * 100);
@@ -972,7 +960,7 @@ export class PDFViewerElement extends PDFViewerBaseElement {
       const result = await this.currentController.saveAttachment(index);
 
       // Cap the PDF attachment size at 100 MB. This cap should be kept in sync
-      // with and is also enforced in pdf/out_of_process_instance.cc.
+      // with and is also enforced in pdf/pdf_view_plugin_base.h.
       const MAX_FILE_SIZE = 100 * 1000 * 1000;
       const bufView = new Uint8Array(result.dataToSave);
       assert(
@@ -1089,7 +1077,8 @@ export class PDFViewerElement extends PDFViewerBaseElement {
     }
 
     LocalStorageProxyImpl.getInstance().setItem(
-        LOCAL_STORAGE_SIDENAV_COLLAPSED_KEY, this.sidenavCollapsed_ ? 1 : 0);
+        LOCAL_STORAGE_SIDENAV_COLLAPSED_KEY,
+        (this.sidenavCollapsed_ ? 1 : 0).toString());
   }
 
   /**
@@ -1112,7 +1101,7 @@ export class PDFViewerElement extends PDFViewerBaseElement {
     if (requestType !== SaveRequestType.ORIGINAL || !this.annotationMode_) {
       result = await this.currentController.save(requestType);
     } else {
-      // <if expr="chromeos">
+      // <if expr="enable_ink">
       // Request type original in annotation mode --> need to exit annotation
       // mode before saving. See https://crbug.com/919364.
       await this.exitAnnotationMode_();
@@ -1155,7 +1144,7 @@ export class PDFViewerElement extends PDFViewerBaseElement {
           });
         });
 
-    // <if expr="chromeos">
+    // <if expr="enable_ink">
     // Saving in Annotation mode is destructive: crbug.com/919364
     this.exitAnnotationMode_();
     // </if>
@@ -1186,7 +1175,7 @@ export class PDFViewerElement extends PDFViewerBaseElement {
   /** @private */
   async onPrint_() {
     record(UserAction.PRINT);
-    // <if expr="chromeos">
+    // <if expr="enable_ink">
     await this.exitAnnotationMode_();
     // </if>
     this.currentController.print();
@@ -1220,7 +1209,9 @@ export class PDFViewerElement extends PDFViewerBaseElement {
 const TOOLBAR_WINDOW_MIN_HEIGHT = 250;
 
 /**
- * The background color used for the regular viewer.
+ * The background color used for the regular viewer. Its decimal value in string
+ * format should match `kPdfViewerBackgroundColor` in
+ * components/pdf/browser/plugin_response_writer.cc.
  * @type {number}
  */
 const BACKGROUND_COLOR = 0xff525659;
