@@ -23,12 +23,7 @@ class AppLauncherPageUI : public content::WebUIController {
   ~AppLauncherPageUI() override;
 
   static base::RefCountedMemory* GetFaviconResourceBytes(
-      ui::ScaleFactor scale_factor);
-
-  // content::WebUIController:
-  bool OverrideHandleWebUIMessage(const GURL& source_url,
-                                  const std::string& message,
-                                  const base::ListValue& args) override;
+      ui::ResourceScaleFactor scale_factor);
 
  private:
   void OnHideWebStoreIconChanged();
