@@ -27,6 +27,9 @@ class ChromeWebContentsHandler
                       WindowOpenDisposition disposition,
                       const gfx::Rect& initial_rect,
                       bool user_gesture) override;
+  void RunFileChooser(content::RenderFrameHost* render_frame_host,
+                      scoped_refptr<content::FileSelectListener> listener,
+                      const blink::mojom::FileChooserParams& params) override;
 
  private:
   DISALLOW_COPY_AND_ASSIGN(ChromeWebContentsHandler);
