@@ -9,9 +9,9 @@
 #include <string>
 #include <vector>
 
-#include "base/optional.h"
 #include "base/strings/string_piece.h"
 #include "components/autofill/core/browser/field_types.h"
+#include "third_party/abseil-cpp/absl/types/optional.h"
 
 namespace re2 {
 class RE2;
@@ -26,6 +26,7 @@ struct SortedTokenComparisonResult;
 // Represents the validation status of value stored in the AutofillProfile.
 // The associated integer values used to store the verification code in SQL and
 // should not be modified.
+// GENERATED_JAVA_ENUM_PACKAGE: org.chromium.chrome.browser.autofill
 enum class VerificationStatus {
   // No verification status assigned.
   kNoStatus = 0,
@@ -39,6 +40,7 @@ enum class VerificationStatus {
   kUserVerified = 4,
   // The token was parsed by the server.
   kServerParsed = 5,
+  kMaxValue = kServerParsed
 };
 
 // Prints the string representation of |status| to |os|.
@@ -177,13 +179,13 @@ class AddressComponent {
 
   // Returns a constant reference to |value_.value()|. If the value is not
   // assigned, an empty string is returned.
-  const base::string16& GetValue() const;
+  const std::u16string& GetValue() const;
 
   // Returns true if the value of this AddressComponent is assigned.
   bool IsValueAssigned() const;
 
   // Sets the value corresponding to the storage type of this AddressComponent.
-  virtual void SetValue(base::string16 value, VerificationStatus status);
+  virtual void SetValue(std::u16string value, VerificationStatus status);
 
   // Sets the value to an empty string, marks it unassigned and sets the
   // verification status to |kNoStatus|.
@@ -199,7 +201,7 @@ class AddressComponent {
   // unassigned. If |invalidate_parent_nodes|, all ancestor nodes of the
   // assigned node as unassigned.
   bool SetValueForTypeIfPossible(const ServerFieldType& type,
-                                 const base::string16& value,
+                                 const std::u16string& value,
                                  const VerificationStatus& verification_status,
                                  bool invalidate_child_nodes = false,
                                  bool invalidate_parent_nodes = false);
@@ -207,7 +209,7 @@ class AddressComponent {
   // Same as |SetValueForTypeIfPossible()| but the type is supplied in the
   // corresponding string representation.
   bool SetValueForTypeIfPossible(const std::string& type_name,
-                                 const base::string16& value,
+                                 const std::u16string& value,
                                  const VerificationStatus& verification_status,
                                  bool invalidate_child_nodes = false,
                                  bool invalidate_parent_nodes = false);
@@ -228,11 +230,11 @@ class AddressComponent {
 
   // Convenience method to get the value of |type|.
   // Returns an empty string if |type| is not supported.
-  base::string16 GetValueForType(const ServerFieldType& type) const;
+  std::u16string GetValueForType(const ServerFieldType& type) const;
 
   // Convenience method to get the value of |type| identified by its string
   // representation name. Returns an empty string if |type| is not supported.
-  base::string16 GetValueForType(const std::string& type) const;
+  std::u16string GetValueForType(const std::string& type) const;
 
   // Convenience method to get the verification status of |type|.
   // Returns |VerificationStatus::kNoStatus| if |type| is not supported.
@@ -254,13 +256,13 @@ class AddressComponent {
   // children. Returns false if the neither the node or one of its ancestors
   // supports |type|.
   bool GetValueAndStatusForTypeIfPossible(const ServerFieldType& type,
-                                          base::string16* value,
+                                          std::u16string* value,
                                           VerificationStatus* status) const;
 
   // Get the value and status of a |type| identified by its name.
   // Returns false if the |type| is not supported by the structure.
   bool GetValueAndStatusForTypeIfPossible(const std::string& type_name,
-                                          base::string16* value,
+                                          std::u16string* value,
                                           VerificationStatus* status) const;
 
   // Returns true if the |value| and |verification_status| were successfully
@@ -384,7 +386,7 @@ class AddressComponent {
   }
 
   // Returns the best format string for testing.
-  base::string16 GetBestFormatStringForTesting() {
+  std::u16string GetBestFormatStringForTesting() {
     return GetBestFormatString();
   }
 
@@ -399,7 +401,7 @@ class AddressComponent {
 
   // Replaces placeholder values in the best format string with the
   // corresponding values.
-  base::string16 GetReplacedPlaceholderTypesWithValuesForTesting() const {
+  std::u16string GetReplacedPlaceholderTypesWithValuesForTesting() const {
     return ReplacePlaceholderTypesWithValues(GetBestFormatString());
   }
 
@@ -413,7 +415,7 @@ class AddressComponent {
   void SetMergeModeForTesting(int merge_mode) { merge_mode_ = merge_mode; }
 
   // Returns the value used for comparison for testing purposes.
-  base::string16 ValueForComparisonForTesting() const {
+  std::u16string ValueForComparisonForTesting() const {
     return ValueForComparison();
   }
 #endif
@@ -429,7 +431,7 @@ class AddressComponent {
 
   // Heuristic method to get the best suited format string.
   // This method is virtual and can be reimplemented for each type.
-  virtual base::string16 GetBestFormatString() const;
+  virtual std::u16string GetBestFormatString() const;
 
   // Returns pointers to regular expressions sorted by their relevance.
   // This method is virtual and can be reimplemented for each type.
@@ -452,7 +454,7 @@ class AddressComponent {
   // It returns true if conversion logic exists and the type can be set.
   virtual bool ConvertAndSetValueForAdditionalFieldTypeName(
       const std::string& field_type_name,
-      const base::string16& value,
+      const std::u16string& value,
       const VerificationStatus& status);
 
   // This method is used to retrieve the value for a supported field type
@@ -462,7 +464,7 @@ class AddressComponent {
   // The method must handle |nullptr|s for both the value and status.
   virtual bool ConvertAndGetTheValueForAdditionalFieldTypeName(
       const std::string& field_type_name,
-      base::string16* value) const;
+      std::u16string* value) const;
 
   // Clears all parsed and formatted values.
   void ClearAllParsedAndFormattedValues();
@@ -476,7 +478,7 @@ class AddressComponent {
   // Can be implemented by the specific node types.
   // The fall-back solution uses the first empty node.
   // If no empty node is available, it appends the value to the first node.
-  virtual void ConsumeAdditionalToken(const base::string16& token_value);
+  virtual void ConsumeAdditionalToken(const std::u16string& token_value);
 
   // Returns a reference to the root node of the tree.
   AddressComponent& GetRootNode();
@@ -495,13 +497,13 @@ class AddressComponent {
   // In the default implementation, this converts the value to lower case and
   // removes white spaces. This function may be reimplemented to perform
   // different normalization operations.
-  virtual base::string16 NormalizedValue() const;
+  virtual std::u16string NormalizedValue() const;
 
   // Returns a value used for comparison.
   // In the default implementation this is just the normalized value but this
   // function can be overridden in subclasses to apply further operations on
   // the normalized value.
-  virtual base::string16 ValueForComparison() const;
+  virtual std::u16string ValueForComparison() const;
 
   // Returns true if the merging of two token identical values should give
   // precedence to the newer value. By default, the newer component gets
@@ -512,7 +514,7 @@ class AddressComponent {
   // Parses |value| by using |parse_expressions| and assigns the values.
   // Returns true on success.
   bool ParseValueAndAssignSubcomponentsByRegularExpression(
-      const base::string16& value,
+      const std::u16string& value,
       const re2::RE2* parse_expression);
 
   // Determines and sets a formatted value using
@@ -536,15 +538,15 @@ class AddressComponent {
 
   // Determines a value from the subcomponents by using the
   // most suitable format string determined by |GetBestFormatString()|.
-  base::string16 GetFormattedValueFromSubcomponents();
+  std::u16string GetFormattedValueFromSubcomponents();
 
   // Replaces placeholder values with the corresponding values.
-  base::string16 ReplacePlaceholderTypesWithValues(
-      const base::string16& format) const;
+  std::u16string ReplacePlaceholderTypesWithValues(
+      const std::u16string& format) const;
 
   // Replaces placeholder values with the corresponding values.
-  base::string16 ReplacePlaceholderTypesWithValuesRegexVersion(
-      const base::string16& format) const;
+  std::u16string ReplacePlaceholderTypesWithValuesRegexVersion(
+      const std::u16string& format) const;
 
   // This method uses regular expressions acquired by
   // |GetParseRegularExpressionsByRelevance| to parse |value_| into the values
@@ -552,7 +554,7 @@ class AddressComponent {
   bool ParseValueAndAssignSubcomponentsByRegularExpressions();
 
   // The unstructured value of this component.
-  base::Optional<base::string16> value_;
+  absl::optional<std::u16string> value_;
 
   // The verification status of |value_| indicates the certainty of the value
   // to be correct.
@@ -568,7 +570,7 @@ class AddressComponent {
   // meaning that it was converted to lower case and diacritics have been
   // removed. |value_| is tokenized by splitting the string by white spaces and
   // commas. It is calculated when |value_| is set.
-  base::Optional<std::vector<AddressToken>> sorted_normalized_tokens_;
+  absl::optional<std::vector<AddressToken>> sorted_normalized_tokens_;
 
   // A pointer to the parent node. It is set to nullptr if the node is the root
   // node of the AddressComponent tree.
