@@ -7,13 +7,14 @@
 
 #include <cstdint>
 #include <cstring>
+#include <ostream>
 
 #include "base/check_op.h"
 #include "base/macros.h"
 #include "base/notreached.h"
-#include "base/optional.h"
 #include "base/strings/string_piece.h"
 #include "build/build_config.h"
+#include "third_party/abseil-cpp/absl/types/optional.h"
 
 // TODO(jrw): Move this file to a more appropriate directory.
 //
@@ -192,7 +193,7 @@ class
       const GenericEnumTableEntry data[],
       std::size_t size,
       base::StringPiece str);
-  static base::Optional<base::StringPiece>
+  static absl::optional<base::StringPiece>
   FindByValue(const GenericEnumTableEntry data[], std::size_t size, int value);
 
   constexpr base::StringPiece str() const {
@@ -302,7 +303,7 @@ class EnumTable {
 
   // Gets the string associated with the given enum value.  When the argument
   // is a constant, prefer the zero-argument form below.
-  inline base::Optional<base::StringPiece> GetString(E value) const {
+  inline absl::optional<base::StringPiece> GetString(E value) const {
     if (is_sorted_) {
       const std::size_t index = static_cast<std::size_t>(value);
       if (ANALYZER_ASSUME_TRUE(index < data_.size())) {
@@ -310,7 +311,7 @@ class EnumTable {
         if (ANALYZER_ASSUME_TRUE(entry.has_str()))
           return entry.str();
       }
-      return base::nullopt;
+      return absl::nullopt;
     }
     return GenericEnumTableEntry::FindByValue(
         reinterpret_cast<const GenericEnumTableEntry*>(data_.begin()),
@@ -340,11 +341,11 @@ class EnumTable {
   // GetString(), this method is not defined as a constexpr, because it should
   // never be called with a literal string; it's simpler to just refer to the
   // enum value directly.
-  base::Optional<E> GetEnum(base::StringPiece str) const {
+  absl::optional<E> GetEnum(base::StringPiece str) const {
     auto* entry = GenericEnumTableEntry::FindByString(
         reinterpret_cast<const GenericEnumTableEntry*>(data_.begin()),
         data_.size(), str);
-    return entry ? static_cast<E>(entry->value) : base::Optional<E>();
+    return entry ? static_cast<E>(entry->value) : absl::optional<E>();
   }
 
   // The default instance of this class.  There should normally only be one
@@ -383,7 +384,7 @@ class EnumTable {
 
 #ifndef NDEBUG
   // Finds and returns the first i for which data[i].value != i;
-  constexpr static base::Optional<std::size_t> FindNonConsecutiveEntry(
+  constexpr static absl::optional<std::size_t> FindNonConsecutiveEntry(
       std::initializer_list<Entry> data) {
     int32_t counter = 0;
     for (const auto& entry : data) {
@@ -402,7 +403,7 @@ class EnumTable {
 // Converts an enum value to a string using the default table
 // (EnumTable<E>::instance) for the given enum type.
 template <typename E>
-inline base::Optional<base::StringPiece> EnumToString(E value) {
+inline absl::optional<base::StringPiece> EnumToString(E value) {
   return EnumTable<E>::GetInstance().GetString(value);
 }
 
@@ -426,7 +427,7 @@ inline base::StringPiece EnumToString() {
 // Converts a string to an enum value using the default table
 // (EnumTable<E>::instance) for the given enum type.
 template <typename E>
-inline base::Optional<E> StringToEnum(base::StringPiece str) {
+inline absl::optional<E> StringToEnum(base::StringPiece str) {
   return EnumTable<E>::GetInstance().GetEnum(str);
 }
 
